@@ -69,34 +69,29 @@ dy.d_ <- function(x, y, wrt,
                   eval.points = "obs",
                   mixed = FALSE,
                   messages = TRUE){
-
-
-
+  
+  
+  
   n <- dim(x)[1]
   l <- dim(x)[2]
-
+  
   if(is.null(l)) stop("Please ensure (x) is a matrix or data.frame type object.")
   if(l < 2) stop("Please use NNS::dy.dx(...) for univariate partial derivatives.")
-
-  results <- list()
-
-
+  
+  
   if(messages) message("Currently generating NNS.reg finite difference estimates...Regressor ", wrt,"\r",appendLF=TRUE)
-
-
+  
+  
   if(is.null(colnames(x))){
-    colnames.list <- list()
-    for(i in 1 : l){
-      colnames.list[i] <- paste0("X", i)
-    }
+    colnames.list <- lapply(1 : ncol(x), function(i) paste0("X", i))
     colnames(x) <- as.character(colnames.list)
   }
-
+  
   if(any(class(x)%in%c("tbl","data.table")))  x <- as.data.frame(x)
   if(!is.null(y) && any(class(y)%in%c("tbl","data.table"))) y <- as.vector(unlist(y))
-
+  
   if(l != 2) mixed <- FALSE
-
+  
   if(is.character(eval.points)){
     eval.points <- tolower(eval.points)
     if(eval.points == "median"){
@@ -117,167 +112,169 @@ dy.d_ <- function(x, y, wrt,
       }
     }
   }
-
+  
   original.eval.points.min <- eval.points
   original.eval.points.max <- eval.points
   original.eval.points <- eval.points
   
-  zz <- NNS.dep(cbind(x,y), ncores = 1)$Dependence^2
-
+  zz <- NNS.dep(cbind(x,y))$Dependence^2
+  
   h_s <- seq(.01, 1, length.out = max(5, ifelse(round(zz[wrt, "y"]*10)>.5, ceiling(round(zz[wrt, "y"]*10)), floor(round(zz[wrt, "y"]*10)))))
-
+  
+  results <- vector(mode = "list", length(h_s))
+  
   for(h in h_s){
     index <- which(h == h_s)
     if(is.vector(eval.points) || dim(eval.points)[2] == 1){
       eval.points <- unlist(eval.points)
-
+      
       h_step <- gravity(abs(diff(LPM.VaR(seq(0, 1, h), 1, x[,wrt]))))
-
+      
       if(h_step==0) h_step <- abs((max(x[,wrt]) - min(x[,wrt])) * h)
-
+      
       original.eval.points.min <- original.eval.points.min - h_step
       original.eval.points.max <- h_step + original.eval.points.max
-
+      
       seq_by <- max(.01, 1 - zz[wrt, "y"])
-
+      
       deriv.points <- apply(x, 2, function(z) LPM.VaR(seq(0,1,seq_by), 1, z))
       sampsize <- length(seq(0, 1, seq_by))
-
+      
       if(dim(deriv.points)[2]!=dim(x)[2]){
         deriv.points <- matrix(deriv.points, ncol = l, byrow = FALSE)
       }
-
-
-
+      
+      
+      
       deriv.points <- data.table::data.table(do.call(rbind, replicate(3*length(eval.points), deriv.points, simplify = FALSE)))
-
+      
       data.table::set(deriv.points, i = NULL, j = as.integer(wrt), value = rep(unlist(rbind(original.eval.points.min,
-                                                                                          eval.points,
-                                                                                          original.eval.points.max))
-                                                                             , each = sampsize, length.out = dim(deriv.points)[1] ))
-
-
+                                                                                            eval.points,
+                                                                                            original.eval.points.max))
+                                                                               , each = sampsize, length.out = dim(deriv.points)[1] ))
+      
+      
       colnames(deriv.points) <- colnames(x)
-
+      
       distance_wrt <- h_step
-
-
+      
+      
       position <- rep(rep(c("l", "m", "u"), each = sampsize), length.out = dim(deriv.points)[1])
       id <- rep(1:length(eval.points), each = 3*sampsize, length.out = dim(deriv.points)[1])
-
-
+      
+      
       if(messages){
         message(paste("Currently evaluating the ", dim(deriv.points)[1], " required points"  ),"\r",appendLF=TRUE)
       }
-
-
+      
+      
       estimates <- NNS.reg(x, y, point.est = deriv.points, dim.red.method = "equal", plot = FALSE, threshold = 0, order = NULL, point.only = TRUE, ncores = 1)$Point.est
-
-
+      
+      
       estimates <- data.table::data.table(cbind(estimates = estimates,
                                                 position = position,
                                                 id = id))
-
+      
       lower_msd <- estimates[position=="l", sapply(.SD, function(x) list(mean=mean(as.numeric(x)), sd=sd(as.numeric(x)))), .SDcols = "estimates", by = id]
       lower <- lower_msd$V1
       lower_sd <- lower_msd$V2
-
+      
       fx_msd <- estimates[position=="m", sapply(.SD, function(x) list(mean=mean(as.numeric(x)), sd=sd(as.numeric(x)))), .SDcols = "estimates", by = id]
       two.f.x <- 2* fx_msd$V1
       two.f.x_sd <- fx_msd$V2
-
+      
       upper_msd <- estimates[position=="u", sapply(.SD, function(x) list(mean=mean(as.numeric(x)), sd=sd(as.numeric(x)))), .SDcols = "estimates", by = id]
       upper <- upper_msd$V1
       upper_msd <- upper_msd$V2
-
+      
       rise_1 <- upper - two.f.x 
       rise_2 <- two.f.x - lower
-
+      
     } else {
-
+      
       n <- dim(eval.points)[1]
       original.eval.points <- eval.points
-
+      
       h_step <- gravity(abs(diff(LPM.VaR(seq(0, 1, h), 1, x[,wrt]))))
-
+      
       if(h_step==0) h_step <- abs((max(x[,wrt]) - min(x[,wrt])) * h)
-
+      
       original.eval.points.min[ , wrt] <- original.eval.points.min[ , wrt] - h_step
       original.eval.points.max[ , wrt] <- h_step + original.eval.points.max[ , wrt]
-
+      
       deriv.points <- rbind(original.eval.points.min,
                             original.eval.points,
                             original.eval.points.max)
-
-      if(messages) message("Currently generating NNS.reg finite difference estimates...bandwidth ", index, " of ", length(h_s),"\r",appendLF=TRUE)
-
-
-      estimates <- NNS.reg(x, y, point.est = deriv.points, dim.red.method = "equal", plot = FALSE, threshold = 0, order = NULL, point.only = TRUE, ncores = 1)$Point.est
-
       
-
+      if(messages) message("Currently generating NNS.reg finite difference estimates...bandwidth ", index, " of ", length(h_s),"\r",appendLF=TRUE)
+      
+      
+      estimates <- NNS.reg(x, y, point.est = deriv.points, dim.red.method = "equal", plot = FALSE, threshold = 0, order = NULL, point.only = TRUE, ncores = 1)$Point.est
+      
+      
+      
       lower <- head(estimates,n)
       two.f.x <- 2 * estimates[(n+1):(2*n)]
       upper <- tail(estimates,n)
-
+      
       rise_1 <- upper - two.f.x 
       rise_2 <- two.f.x - lower
-
+      
       distance_wrt <- h_step
     }
-
-
+    
+    
     if(mixed){
       if(is.null(dim(eval.points))){
         if(length(eval.points)!=2) stop("Mixed Derivatives are only for 2 IV")
       } else {
         if(ncol(eval.points) != 2) stop("Mixed Derivatives are only for 2 IV")
       }
-
+      
       if(!is.null(dim(eval.points))){
         h_step_1 <- gravity(abs(diff(LPM.VaR(seq(0, 1, h), 1, x[,2]))))
         if(h_step_1==0) h_step_1 <- abs((max(x[,1]) - min(x[,1])) * h)
-
-
+        
+        
         h_step_2 <- gravity(abs(diff(LPM.VaR(seq(0, 1, h), 1, x[,2]))))
         if(h_step_2==0) h_step_2 <- abs((max(x[,2]) - min(x[,2])) * h)
-
+        
         mixed.deriv.points <- matrix(c(h_step_1 + eval.points[,1], h_step_2 + eval.points[,2],
                                        eval.points[,1] - h_step_1, h_step_2 + eval.points[,2],
                                        h_step_1 + eval.points[,1], eval.points[,2] - h_step_2,
                                        eval.points[,1] - h_step_1, eval.points[,2] - h_step_2), ncol = 2, byrow = TRUE)
-
+        
         mixed.distances <- 4 * (h_step_1  * h_step_2)
-
+        
       } else {
         mixed.deriv.points <- matrix(c(h_step + eval.points,
                                        eval.points[1] - h_step, h_step + eval.points[2],
                                        h_step + eval.points[1], eval.points[2] - h_step,
                                        eval.points - h_step), ncol = 2, byrow = TRUE)
-
+        
         mixed.distances <- 4 * (h_step^2)
       }
-
-
+      
+      
       mixed.estimates <- NNS.reg(x, y, point.est = mixed.deriv.points, dim.red.method = "equal", plot = FALSE, threshold = 0, order = NULL, point.only = TRUE, ncores = 1)$Point.est
-
-
+      
+      
       z <- matrix(mixed.estimates, ncol=4, byrow=TRUE)
       z <- z[,1] + z[,4] - z[,2] - z[,3]
       mixed <- (z / mixed.distances)
-
+      
       results[[index]] <- list("First" = (rise_1 + rise_2)/(2 * distance_wrt),
                                "Second" = (upper - two.f.x + lower) / ((distance_wrt) ^ 2),
                                "Mixed" = mixed)
-
+      
     } else {
       results[[index]] <- list("First" = (rise_1 + rise_2)/(2 * distance_wrt),
                                "Second" = (upper - two.f.x + lower) / ((distance_wrt) ^ 2) )
     }
-
-
+    
+    
   }
-
+  
   if(mixed){
     final_results <- list("First" = apply((do.call(cbind, (lapply(results, `[[`, 1)))), 1, function(x) gravity(rep(x, length(x):1))),
                           "Second" = apply((do.call(cbind, (lapply(results, `[[`, 2)))), 1, function(x) gravity(rep(x, length(x):1))),
@@ -285,11 +282,11 @@ dy.d_ <- function(x, y, wrt,
   } else {
     final_results <- list("First" = apply((do.call(cbind, (lapply(results, `[[`, 1)))), 1, function(x) gravity(rep(x, length(x):1))),
                           "Second" = apply((do.call(cbind, (lapply(results, `[[`, 2)))), 1, function(x) gravity(rep(x, length(x):1))))
-
+    
   }
   if(messages) message("Done :-)","\r",appendLF=TRUE)
   return(final_results)
-
+  
 }
 
-dy.d_ <- Vectorize(dy.d_, vectorize.args = c("wrt"))
+dy.d_ <- Vectorize(dy.d_, vectorize.args = c("wrt"))
\ No newline at end of file
